@@ -31,4 +31,6 @@ from .api import distribution_sentiment_terrorist_tweets
 from .api import close_duplicates
 from .api import duplicates_detection
 from .api import graph_json_values
-from .api import graph_algoritm_selected
\ No newline at end of file
+from .api import graph_algoritm_selected
+from .api import basic_metadata_tweets_extracted
+from .api import simple_user_timeline_extraction
\ No newline at end of file
