@@ -70,7 +70,6 @@ def profile_connections (data_tweets):
     data_tweets = data_tweets.rename(columns = {"created_at": "created_at_tw"})
     data_tweets = pd.concat([data_tweets.drop(['user'], axis=1), data_tweets['user'].apply(pd.Series)],
                             axis=1).drop_duplicates().reset_index(drop=True)
-    print(data_tweets.dtypes)
     if(data_tweets.empty == False):
         for i in range(len(data_tweets)):
             screen_name.append(data_tweets["screen_name"][i])
@@ -110,8 +109,9 @@ def basic_metadata_tweets_extracted (data_tweets, node_list):
         
     data_tweets = data_tweets.rename(columns = {"created_at": "created_at_tw"})
     df_basic_metadata_tweets_extracted = pd.concat([data_tweets.drop(['user'], axis=1), data_tweets['user'].apply(pd.Series)],
-                            axis=1).drop_duplicates().reset_index(drop=True)[["screen_name","followees","followers","url"]]
-    
+                            axis=1).drop_duplicates().reset_index(drop=True)[["screen_name","followees","followers","statuses_count","url"]]
+    df_basic_metadata_tweets_extracted["url"] = "http://www.twitter.com/"+df_basic_metadata_tweets_extracted["screen_name"]
+
     extract_profiles =[]
     tweets_profiles =  list(df_basic_metadata_tweets_extracted["screen_name"])
     for item in node_list:
@@ -379,15 +379,32 @@ def graph_features(DiG,df):
     output = merge_dataframes(output, df_nodes_self_loop_iteration)
     return output
     
-def graph_json_values(df_graph, df_algComu):
+def graph_json_values(df_graph, df_basic_data, node_list_df):
+
+    #Removing incorrect profile mentions
+    tweets_profiles =  list(df_basic_data["screen_name"])
+    node_list = list(node_list_df["nodes"])
+    
+    delete_profiles = []            
+    for item in node_list:
+        if item not in tweets_profiles:
+            delete_profiles.append(item)
+
+    df_graph = df_graph[~df_graph["screen_name"].isin(delete_profiles)]
+    df_graph = df_graph[~df_graph["screen_name_mention"].isin(delete_profiles)] 
     
     data = {}
     data['nodes'] = []
-    for i in range(len(df_algComu)):
+    for i in range(len(df_basic_data)):
       
       data['nodes'].append({
-          'screen_name': df_algComu["screen_name"].iloc[i],
-          'community': str(df_algComu["community"].iloc[i])
+          'screen_name': df_basic_data["screen_name"].iloc[i],
+          'community': str(df_basic_data["community"].iloc[i]),
+          "community_degree_mean": float(df_basic_data["community_degree_mean"].iloc[i]),
+          'followers': int(df_basic_data["followers"].iloc[i]),
+          'following': int(df_basic_data["followees"].iloc[i]),
+          'statuses_count': int(df_basic_data["statuses_count"].iloc[i]),
+          'url': str(df_basic_data["url"].iloc[i])
       })
       
     data['edges'] = []
@@ -461,7 +478,6 @@ def simple_user_timeline_extraction(node_list, consumerKey, consumerSecret,acces
             aux.append(tweets_user[i][j]._json)     
       if(len(aux) != 0):  
         df = pd.DataFrame(aux)
-        print(df.dtypes)
         df = df.rename(columns = {"created_at": "created_at_tw"})
         df= df.rename(columns = {"lang": "lang_tw"})
         df = pd.concat([df.drop(['user'], axis=1), df['user'].apply(pd.Series)], axis=1)
@@ -471,6 +487,7 @@ def simple_user_timeline_extraction(node_list, consumerKey, consumerSecret,acces
                               "favorite_count": "favorites",
                               "favourites_count": "favorites_count",
                               "full_text": "text"})
+        df2["url"] = "http://www.twitter.com/"+df2["screen_name"]
         if path.exists(os.path.join(filepath,filename+".csv")):
           df2.to_csv(path_or_buf =os.path.join(filepath,filename+".csv"),mode="a", index=False, header=False)
         else:
